%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Technical Note 145
% Parameters for 'Space vector modulation (SVM)' system
% Copyright imperix ltd, 2021
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Controller parameters

ControlFreq    = 20e3;              % Control interrupt frequency [Hz]
ControlPeriod  = 1/ControlFreq;     % Control interrupt period [s]
SamplingPeriod = ControlPeriod;     % Sampling period [s]

DeadTime = 1e-6;                  % Deadtime duration [s]

%% Plant model

L = 2.5e-3;                         % Load inductance [H]
R = 8.5;                            % Load inductor resistance [Ohm]

Vdc = 100;                          % Dc bus voltage [V]
Cdc = 250e-6;                       % Dc bus capacitance [F]


%% Closed-loop current control

f = 50;                             % Fundamental frequency [Hz]

% Plant parameters
K1 = 1/R;
T1 = L/R;

Ts = ControlPeriod;                 % Current controller period [s]
Tsens = 0.5*Ts;                     % Sensing delay [s]
Tctrl = 0.5*Ts;   		            % Control delay [s]
Tpwm  = 0.5*ControlPeriod;	        % Modulator delay [s]

Kcm  = 1;
Ttot = Tctrl + Tpwm + Tsens;        % Total controller delay [s]

% PI controller tuning (magnitude optimum criteria)
Tn = T1;
Ti = 2*Kcm*K1*Ttot;

Kp = Tn/Ti;
Ki = 1/Ti;